%% PTrussDrawModel.m
%  Draws the model on a figure
%  This file is part of the PTrussMatlab program


%% Generate model figure
figure(1) %Initialize figure 1
clf(1) %Clear figure 1

xmin = min(NodesCoordinates(:,1)); %Minimum x-coordinate
xmax = max(NodesCoordinates(:,1)); %Maximum x-coordinate
ymin = min(NodesCoordinates(:,2)); %Minimum y-coordinate
ymax = max(NodesCoordinates(:,2)); %Maximum y-coordinate

axis([xmin-1 xmax+1 ymin-1 ymax+1]); %Initialize axes


%% Draw elements and element properties
for n=1:NumElements; %Scan all elements
	PTrussAssignElementProperties;  %Get properties for n element
    line([x1 x2],[y1 y2],[0 0],'Marker','.','MarkerSize',15,'LineStyle','-','LineWidth',2,'Color',[0 0 0]); %Draw line for n element
    element_id=sprintf('%i',n);
    x_60=(0.6*NodesCoordinates(Node_i,1)+0.4*NodesCoordinates(Node_j,1)); %x-coordinate at 60% of the length of n element
    y_60=(0.6*NodesCoordinates(Node_i,2)+0.4*NodesCoordinates(Node_j,2)); %y-coordinate at 60% of the length of n element
    text(x_60,y_60,element_id,'FontSize',11,'FontWeight','bold','HorizontalAlignment','center','VerticalAlignment','bottom','Color',[1 0 0]);
end


%% Draw node constraints
for n=1:NumNodes; %Scan all nodes
    node_id=sprintf('  %i',n);
    text(NodesCoordinates(n,1),NodesCoordinates(n,2),node_id,'FontSize',12,'FontWeight','bold','HorizontalAlignment','left','Color',[0 0 1]);
    if BoundaryConditions(n,1)~=0 || BoundaryConditions(n,2)~=0
        for i=1:2
            if BoundaryConditions(n,i)==1
                    constraint=sprintf(' x ');
            else
                    constraint=sprintf(' o ');
            end
            switch i
                case 1
                    text(NodesCoordinates(n,1),NodesCoordinates(n,2),constraint,'FontSize',12,'FontWeight','bold','HorizontalAlignment','right','VerticalAlignment','top','Color',[0 1 0]);
                case 2
                    text(NodesCoordinates(n,1),NodesCoordinates(n,2),constraint,'FontSize',12,'FontWeight','bold','HorizontalAlignment','center','VerticalAlignment','top','Color',[0 1 0]);
            end
        end
    end
end


%% Draw labels, etc
grid on; %Draw grid
xlabel('x Coordinate','FontSize',12)
ylabel('y Coordinate','FontSize',12)

FigureTitle=['PTrussMatlab Model Geometry : ' InputFileName];

title(FigureTitle,'FontSize',12)
axis equal

% End of file -------------------------------------------------------------